# -*- coding: utf-8 -*-
""" MCWPy - Minecraft With Python

MCWPy is a Python library for creating Minecraft datapacks using Python.
    https://github.com/vianneyveremme/minecraft_with_python
"""
import sys
import warnings


# Checking Python version (should be above 3.9.5)
if sys.version_info < (3, 9, 5):
    warnings.warn("For optimal results it is recommended to use Python 3.9.5 or above.", RuntimeWarning)



from setuptools import setup, find_packages


classifiers = [
    'Development Status :: 1 - Planning',
    'Intended Audience :: Customer Service',
    'Intended Audience :: Developers',
    'Intended Audience :: Education',
    'Intended Audience :: End Users/Desktop',
    'Operating System :: OS Independent',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name='mcwpy',
    version='0.0.2',
    description='A new way to create Minecraft datapacks',
    long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.md').read(),
    long_description_content_type='text/markdown',
    author='Vianpyro',
    author_email='vianney.veremme@gmail.com',
    url='https://github.com/vianneyveremme/minecraft_with_python',
    license='MIT',
    keywords=['Minecraft', 'Datapack', 'Function', 'MCFunction'],
    classifiers=classifiers,
    packages=find_packages(exclude=['tests']),
    install_requires=open('REQUIREMENTS.txt').read(),
    zip_safe=False
)
